<?php

namespace App\Console;

use App\Service\DatabaseService;
use App\Service\Traits\SelectDatabaseQuestion;
use App\Service\Traits\SelectUserQuestion;
use Symfony\Component\Console\Attribute\AsCommand;
use Symfony\Component\Console\Command\Command;
use Symfony\Component\Console\Input\InputArgument;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Output\OutputInterface;
use Symfony\Component\Console\Question\ChoiceQuestion;

#[AsCommand('app:permission:create')]
class CreatePermissionCommand extends Command
{
    use SelectDatabaseQuestion;
    use SelectUserQuestion;

    public function __construct(
        private readonly DatabaseService $db,
    )
    {
        parent::__construct();
    }

    public function configure(): void
    {
        $this->addArgument('user', InputArgument::OPTIONAL, 'User name');
        $this->addArgument('database', InputArgument::OPTIONAL, 'Database');
        $this->addArgument('host', InputArgument::OPTIONAL, 'User host');
    }

    protected function execute(InputInterface $input, OutputInterface $output): int
    {
        $question = $this->getHelper('question');

        $user = $this->getUserName($input, $output);
        $host = $input->getArgument('host');

        $permissionTypeQuestion = new ChoiceQuestion('Permission type: ', [
            'admin' => 'Admin',
            'db_admin' => 'Database admin',
        ]);

        $permissionType = $question->ask($input, $output, $permissionTypeQuestion);
        if ($permissionType === 'admin') {
            throw new \Exception('Not implemented');
        } else {
            $db = $this->getDatabaseName($input, $output);
            $this->db->grantDatabaseAdminPermission($user, $db, $host);

            $output->writeln(sprintf('Database admin permission granted to "%s" on "%s"', $user, $db));
        }

        return Command::SUCCESS;
    }
}