<?php

namespace App\Console;

use App\Service\DatabaseService;
use App\Service\Traits\SelectUserQuestion;
use Symfony\Component\Console\Attribute\AsCommand;
use Symfony\Component\Console\Command\Command;
use Symfony\Component\Console\Input\InputArgument;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Output\OutputInterface;
use Symfony\Component\Console\Style\SymfonyStyle;

#[AsCommand('app:permission:list')]
class ListPermissionsCommand extends Command
{
    use SelectUserQuestion;

    public function __construct(
        private readonly DatabaseService $db,
    )
    {
        parent::__construct();
    }

    public function configure(): void
    {
        $this->addArgument('user', InputArgument::OPTIONAL, 'User name');
        $this->addArgument('host', InputArgument::OPTIONAL, 'User host');
    }

    protected function execute(InputInterface $input, OutputInterface $output): int
    {
        $style = new SymfonyStyle($input, $output);

        $host = $input->getArgument('host');
        $user = $this->getUserName($input, $output);

        $permissions = $this->db->listPermissions($user, $host);

        $table = $style
            ->createTable()
            ->setHeaders(['Permission'])
            ->setHeaderTitle(sprintf('List of users for %s@%s', $user, $host))
        ;
        foreach ($permissions as $permission) {
            $table->addRow([$permission]);
        }
        $table->render();

        return Command::SUCCESS;
    }
}